package com.empresa.intranet.modelo.incidencias;

import com.empresa.intranet.modelo.origenes.Origen;
import com.empresa.intranet.modelo.tiendas.Tienda;
import com.empresa.intranet.modelo.util.GenericDaoHibernate;
import java.util.Date;
import java.util.List;
import javax.management.InstanceNotFoundException;
import org.springframework.stereotype.Repository;


@Repository("incidenciaDao")
public class IncidenciaDaoHibernate extends
		GenericDaoHibernate<Incidencia, Long> implements IncidenciaDao {
    @Override
    public List<Incidencia> buscarporTienda(Tienda tienda) throws InstanceNotFoundException {
            List<Incidencia> incidencias = getSession().createQuery(
                            "SELECT u FROM Incidencia u WHERE u.idTienda = :id")
                            .setParameter("id", tienda.getId()).list();

            if (incidencias == null || incidencias.isEmpty()) {
                            throw new InstanceNotFoundException("No se han encontrado incidencias de la tienda "+tienda.getNombre());
            } else {
                    return incidencias;
            }



            }        
        
        @Override
	public List<Incidencia> buscarporDescripcion(String descripcion) throws InstanceNotFoundException {

    	List<Incidencia> incidencias = getSession().createQuery(
    			"SELECT u FROM Incidencia u WHERE u.[descripción] like (%:descripcion%)")
    			.setParameter("descripcion", descripcion).list();

    	if (incidencias == null || incidencias.isEmpty()) {
   			throw new InstanceNotFoundException("No se han encontrado incidencias con la descripción "+descripcion);
    	} else {
    		return incidencias;
    	}
    	
	}          

        @Override
	public List<Incidencia> buscarporFecha(Date fecha) throws InstanceNotFoundException {

    	List<Incidencia> incidencias = getSession().createQuery(
    			"SELECT u FROM Incidencia u WHERE u.fecha = :fecha")
    			.setParameter("fecha", fecha).list();
    	if (incidencias == null || incidencias.isEmpty()) {
   			throw new InstanceNotFoundException("No se han encontrado incidencias en el día "+fecha);
    	} else {
    		return incidencias;
    	}
    	
	}         
        
    @Override
    public int numeroIncidencias() {
        long n = (Long) getSession().createQuery(
        "SELECT COUNT(i) FROM Incidencia i").
        uniqueResult();	
        return (int) n;
    }        
    
    @Override
    public int numeroIncidencias(Long idTienda) {
        long n = (Long) getSession().createQuery(
        "SELECT COUNT(i) FROM Incidencia i WHERE i.tienda.id = :id")
        .setParameter("id", idTienda)
        .uniqueResult();	
        return (int) n;
    } 
    
    @Override
    public List<Incidencia> listaIncidencias(int startIndex, int count) {
        return getSession().createQuery(
	        	"SELECT i FROM Incidencia i " +
	        	"ORDER BY i.id asc").
	           	setFirstResult(startIndex).
	           	setMaxResults(count).list();
    }   
    
    
    @Override
    public List<Incidencia> listaIncidencias(int startIndex, int count, Long idTienda) throws InstanceNotFoundException{
        
        List<Incidencia> incidencias = getSession().createQuery(
                            "SELECT u FROM Incidencia u WHERE u.tienda.id = :id ORDER BY u.id asc")
                            .setParameter("id", idTienda).setFirstResult(startIndex).
	           	setMaxResults(count).list();

            if (incidencias == null || incidencias.isEmpty()) {
                            throw new InstanceNotFoundException("No se han encontrado incidencias de la tienda ");
            } else {
                    return incidencias;
            }
    } 

}