package com.empresa.intranet.modelo.serviciotienda;

import com.empresa.intranet.modelo.incidencias.Incidencia;
import com.empresa.intranet.modelo.incidencias.IncidenciaDao;
import com.empresa.intranet.modelo.lineaspedidos.LineaPedido;
import com.empresa.intranet.modelo.lineaspedidos.LineaPedidoDao;
import com.empresa.intranet.modelo.origenes.Origen;
import com.empresa.intranet.modelo.origenes.OrigenDao;
import com.empresa.intranet.modelo.pedidos.Pedido;
import com.empresa.intranet.modelo.pedidos.PedidoDao;
import com.empresa.intranet.modelo.tiendas.Tienda;
import com.empresa.intranet.modelo.tiendas.TiendaDao;
import com.empresa.intranet.modelo.tipos.Tipo;
import com.empresa.intranet.modelo.tipos.TipoDao;
import java.util.Date;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.management.InstanceNotFoundException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service("tiendaService")
@Transactional
public class ServicioTiendaImp implements ServicioTienda {

    @Autowired
    private TiendaDao tiendaDao;
    @Autowired
    private IncidenciaDao incidenciaDao;
    @Autowired
    private OrigenDao origenDao;
    @Autowired
    private TipoDao tipoDao;    
    @Autowired
    private PedidoDao pedidoDao;        
    @Autowired
    private LineaPedidoDao lineapedidoDao;    

    @Override
    public Tienda crearTienda(Tienda tienda) {
        Long id = tiendaDao.create(tienda);
        return tiendaDao.read(id);
    }
    
    @Override
    public void eliminarTienda(Tienda tienda) {
        tiendaDao.delete(tienda);        
    }
    
    @Override
    public void modificarTienda(Tienda tienda) {
        tiendaDao.update(tienda);        
    }
    
    @Override
    public Tienda buscarTienda(String nombre) {
        try {
            return tiendaDao.buscartienda(nombre);
        } catch (InstanceNotFoundException ex) {
            Logger.getLogger(ServicioTiendaImp.class.getName()).log(Level.SEVERE, null, ex);
            return null;
        }
    }
    
    @Override
    public Incidencia crearIncidencia(Incidencia incidencia) {
        Long id = incidenciaDao.create(incidencia);
        return incidenciaDao.read(id);
    }
    
    @Override
    public void eliminarIncidencia(Incidencia incidencia) {
        incidenciaDao.delete(incidencia);
    }
    
    @Override
    public void modificarIncidencia(Incidencia incidencia) {
        incidenciaDao.update(incidencia);
    }    
    @Override
    public List<Incidencia> buscarporTienda(Tienda tienda) throws InstanceNotFoundException{
        try {
            return incidenciaDao.buscarporTienda(tienda);
        } catch (InstanceNotFoundException ex) {
            Logger.getLogger(ServicioTiendaImp.class.getName()).log(Level.SEVERE, null, ex);
        }
        return null;
    }
    
    @Override
    public List<Incidencia> buscarporfecha(Date fecha) throws InstanceNotFoundException{
        try {
            return incidenciaDao.buscarporFecha(fecha);
        } catch (InstanceNotFoundException ex) {
            Logger.getLogger(ServicioTiendaImp.class.getName()).log(Level.SEVERE, null, ex);
        }
        return null;
    }
    
    @Override
    public List<Incidencia> buscarpordescripcion(String descripcion) throws InstanceNotFoundException{
        try {
            return incidenciaDao.buscarporDescripcion(descripcion);
        } catch (InstanceNotFoundException ex) {
            Logger.getLogger(ServicioTiendaImp.class.getName()).log(Level.SEVERE, null, ex);
        }
        return null;
    }      
    
    @Override
    public int numeroIncidencias() {
        return incidenciaDao.numeroIncidencias();
    } 
    
    @Override
    public int numeroIncidencias(Long idTienda) {
        return incidenciaDao.numeroIncidencias(idTienda);
    } 
    
    @Override
    public List<Incidencia> listaIncidencias(int startIndex, int count)  {
            return incidenciaDao.listaIncidencias(startIndex, count);        
    } 
    
    @Override
    public List<Incidencia> listaIncidencias(int startIndex, int count, Long idTienda) throws InstanceNotFoundException {
        return incidenciaDao.listaIncidencias(startIndex, count, idTienda);
    } 
    
    @Override
    public Incidencia leerIncidencia(Long id){
        return incidenciaDao.read(id);
    }
    
    
    @Override
    public Origen crearOrigen(Origen origen) {
        Long id = origenDao.create(origen);
        return origenDao.read(id);
    }
    
    @Override
    public void eliminarOrigen(Origen origen) {
        origenDao.delete(origen);        
    }    
    
    @Override
    public void modificarOrigen(Origen origen) {
        origenDao.update(origen);        
    }      
   
    @Override
    public Tipo leerTipo(Long id){
        return tipoDao.read(id);
    }
    
    @Override
    public Tipo crearTipo(Tipo tipo) {
        Long id = tipoDao.create(tipo);
        return tipoDao.read(id);
    }
    
    @Override
    public void eliminarTipo(Tipo tipo) {
        tipoDao.delete(tipo);
    }    
    
    @Override
    public void modificarTipo(Tipo tipo) {
        tipoDao.update(tipo);
    }     
    
    @Override
    public Pedido crearPedido(Pedido pedido) {
        Long id = pedidoDao.create(pedido);
        return pedidoDao.read(id);
    }
    
    @Override
    public void eliminarPedido(Pedido pedido) {
        pedidoDao.eliminaLineasPedido(pedido.getId());
        pedidoDao.delete(pedido);
    } 
    
    @Override
    public void modificarPedido(Pedido pedido) {
        pedidoDao.update(pedido);
    }    
    
    
    @Override
    public Pedido leerPedido(Long id){
        return pedidoDao.read(id);
    }    
    
    @Override
    public List<Pedido> listaPedidos(int startIndex, int count) {        
        return pedidoDao.listaPedidos(startIndex, count);        
    }
    
    @Override
    public List<Pedido> listaPedidos(int startIndex, int count,Long idTienda) throws InstanceNotFoundException {        
        return pedidoDao.listaPedidos(startIndex, count, idTienda);        
    }    
          
    @Override
    public int numeroPedidos() {
        return pedidoDao.numeroPedidos();
    }    
    
    @Override
    public int numeroPedidos(Long idTienda) {
        return pedidoDao.numeroPedidos(idTienda);
    }       
               
    
    @Override
    public LineaPedido crearLineaPedido(LineaPedido lineapedido) {
        Long id = lineapedidoDao.create(lineapedido);
        return lineapedidoDao.read(id);
    }
    
    @Override
    public void eliminarLineaPedido(LineaPedido lineapedido) {
        lineapedidoDao.delete(lineapedido);
    } 
     
    
    @Override
    public void modificarLineaPedido(LineaPedido lineapedido) {
        lineapedidoDao.update(lineapedido);
    }      

    @Override
    public int numeroLineasPedidos(Long idPedido) {
         return lineapedidoDao.numeroLineasPedidos(idPedido);
    }
    
    @Override
    public List<LineaPedido> listaLineasPedidos(Long idPedido) {
        return lineapedidoDao.listaLineasPedidos(idPedido);
    }
    
    @Override
    public int numeroTiendas() {
        return tiendaDao.numeroTiendas();
    }

    @Override
    public List<Tienda> listaTiendas(int startIndex, int count) {
        return tiendaDao.listaTiendas(startIndex, count);
    }
    
    @Override
    public Tienda leerTienda(Long id) {
        return tiendaDao.read(id);
    }    
    
    @Override
    public int numeroTipos() {
        return tipoDao.numeroTipos();
    }

    @Override
    public List<Tipo> listaTipos(int startIndex, int count) {
        return tipoDao.listaTipos(startIndex, count);
    }   
    
    @Override
    public int numeroOrigenes() {
        return origenDao.numeroOrigenes();
    }

    @Override
    public List<Origen> listaOrigenes(int startIndex, int count) {
        return origenDao.listaOrigenes(startIndex, count);
    }      
       
    @Override
    public Origen leerOrigen(Long id) {
        return origenDao.read(id);
    }       
    
    
    
}
