package com.empresa.intranet.modelo.serviciousuario;
import com.empresa.intranet.modelo.pedidos.Pedido;
import com.empresa.intranet.modelo.roles.Rol;
import com.empresa.intranet.modelo.perfilusuario.PerfilUsuario;
import com.empresa.intranet.modelo.perfilusuario.PerfilUsuarioDao;
import com.empresa.intranet.modelo.roles.RolDao;
import com.empresa.intranet.modelo.serviciousuario.PasswordIncorectaException;
import com.empresa.intranet.modelo.serviciousuario.PerfilUsuarioDetalle;
import com.empresa.intranet.modelo.serviciousuario.util.PasswordHasher;
import com.empresa.intranet.modelo.tiendas.Tienda;
import com.empresa.intranet.modelo.tiendas.TiendaDao;
import com.empresa.intranet.modelo.util.DuplicatedInstanceException;
import java.util.List;
import javax.management.InstanceNotFoundException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

//Con esto le indicamos a Spring que esta es la implementación por defecto de la interfaz userService
@Service("perfilUsuarioService")
//Le decimos a Hibernate que cada método de esta clase se ejecute en una transacción
@Transactional
public class ServicioUsuarioImpl implements ServicioUsuario {

    @Autowired
    //Con esto le indicamos a Spring que cree un objeto de la clase PerfilUsuarioDao
    private PerfilUsuarioDao perfilUsuarioDao;
    
    @Autowired
    private RolDao rolDao;
    
    @Autowired
    private TiendaDao tiendaDao;    

    @Override
    public Rol registerRol(Rol rol) {
        Long id = rolDao.create(rol);
        return rolDao.read(id);
    }
    
    @Override
    public Tienda registerTienda(Tienda tienda) {
        Long id = tiendaDao.create(tienda);
        return tiendaDao.read(id);
    }
    
    @Override
    public PerfilUsuario registerUser(String loginName, String clearPassword,
            PerfilUsuarioDetalle perfilUsuarioDetails)
            throws DuplicatedInstanceException {

        try {
            perfilUsuarioDao.findByLoginName(loginName);
            throw new DuplicatedInstanceException(loginName,
                    PerfilUsuario.class.getName());
        } catch (InstanceNotFoundException e) {
            String encryptedPassword = PasswordHasher.hash(clearPassword);

            PerfilUsuario perfilUsuario = new PerfilUsuario(loginName,
                    encryptedPassword, perfilUsuarioDetails.getFirstName(),
                    perfilUsuarioDetails.getLastName(), perfilUsuarioDetails
                        .getEmail(), perfilUsuarioDetails.getRol(),perfilUsuarioDetails.getTienda());

            perfilUsuarioDao.create(perfilUsuario);
            return perfilUsuario;
        }

    }

    @Override
    @Transactional(readOnly = true)
    public PerfilUsuario login(String loginName, String password,
            boolean passwordIsEncrypted) throws InstanceNotFoundException,
            PasswordIncorectaException {

        PerfilUsuario perfilUsuario = perfilUsuarioDao.findByLoginName(loginName);
        String storedPassword = perfilUsuario.getEncryptedPassword();

        if (passwordIsEncrypted) {
            if (!password.equals(storedPassword)) {
                throw new PasswordIncorectaException(loginName);
            }
        } else {
            if (!PasswordHasher.match(password, storedPassword)) {
                throw new PasswordIncorectaException(loginName);
            }
        }
        return perfilUsuario;

    }

    @Override
    @Transactional(readOnly = true)
    public PerfilUsuario findPerfilUsuario(Long perfilUsuarioId)
            throws InstanceNotFoundException {
        
        PerfilUsuario perfilUsuario = perfilUsuarioDao.read(perfilUsuarioId);
        if(perfilUsuario == null) { 
            throw new InstanceNotFoundException();
        }
        
        return perfilUsuario;
    }

    @Override
    public void updatePerfilUsuarioDetails(Long perfilUsuarioId,
            PerfilUsuarioDetalle perfilUsuarioDetails)
            throws InstanceNotFoundException {

        PerfilUsuario perfilUsuario = perfilUsuarioDao.read(perfilUsuarioId);
        if(perfilUsuario == null) { 
            throw new InstanceNotFoundException();
        }
         
        perfilUsuario.setFirstName(perfilUsuarioDetails.getFirstName());
        perfilUsuario.setLastName(perfilUsuarioDetails.getLastName());
        perfilUsuario.setEmail(perfilUsuarioDetails.getEmail());

    }

    @Override
    public void changePassword(Long perfilUsuarioId, String oldClearPassword,
            String newClearPassword) throws PasswordIncorectaException,
            InstanceNotFoundException {

        PerfilUsuario perfilUsuario;
        perfilUsuario = perfilUsuarioDao.read(perfilUsuarioId);
         if(perfilUsuario == null) { 
            throw new InstanceNotFoundException();
        }
         
        String storedPassword = perfilUsuario.getEncryptedPassword();

        if (!PasswordHasher.match(oldClearPassword,
                storedPassword)) {
            throw new PasswordIncorectaException(perfilUsuario.getLoginName());
        }

        perfilUsuario.setEncryptedPassword(PasswordHasher
                .hash(newClearPassword));

    }
  
    @Override
      public Rol getRol(Long rolId) {
            return rolDao.read(rolId);
      }
    
    @Override
      public Tienda getTienda(Long tiendaId) {
            return tiendaDao.read(tiendaId);
      }    
    
    @Override
    public int numeroPerfiles() {
        return perfilUsuarioDao.numeroPerfiles();
    } 
    
    @Override
    public List<PerfilUsuario> listaPerfiles(int startIndex, int count) {        
        return perfilUsuarioDao.listaPerfiles(startIndex, count);        
    }     
    
    @Override
    public void eliminarPerfilUsuario(Long perfilUsuarioId) {
        PerfilUsuario perfilUsuario = perfilUsuarioDao.read(perfilUsuarioId);
        perfilUsuarioDao.delete(perfilUsuario);
    }
    
    @Override
    public PerfilUsuario leerUsuario(Long id){
        PerfilUsuario perfilUsuario = perfilUsuarioDao.read(id);
        return perfilUsuario;
        
    }
}
