package com.empresa.intranet.web.pages.tienda;

import com.empresa.intranet.modelo.lineaspedidos.LineaPedido;
import com.empresa.intranet.modelo.pedidos.Pedido;
import com.empresa.intranet.modelo.serviciotienda.ServicioTienda;
import com.empresa.intranet.web.services.AuthenticationPolicy;
import com.empresa.intranet.web.services.AuthenticationPolicyType;
import com.empresa.intranet.web.util.UserSession;
import java.util.ArrayList;
import java.util.List;
import org.apache.tapestry5.annotations.Component;
import org.apache.tapestry5.annotations.InjectPage;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.corelib.components.Form;
import org.apache.tapestry5.corelib.components.TextField;
import org.apache.tapestry5.ioc.Messages;
import org.apache.tapestry5.ioc.annotations.Inject;


//se le indica qué usuarios (todos, sólo autenticados, etc) pueden acceder a la pagina
@AuthenticationPolicy(AuthenticationPolicyType.AUTHENTICATED_USERS)
public class CrearLineasPedido{

    @Property
    //Con eso podemos hacer el mapeo en el tml
    private String numerolinea;
    @Property
    private String codigo;         
    @Property
    private String descripcion;      
    @Property
    private String cantidad;      
    @Property
    private String precio;      
    @Property
    private String importe;      
    
    private Pedido pedido; 
    
     @Property
    //Con eso podemos hacer el mapeo en el tml
    private Long pedidoId;  

    private List<Pedido> listapedidos = new ArrayList<Pedido>();
    
    //Recupero los datos de la sesión del usuario
    @SessionState(create=false)
    private UserSession userSession;
   
    
    //Para recuperar la instancia del servicio del modelo
    @Inject
    private ServicioTienda tiendaService;

    //Elementos que hay en la página tml
    @Component
    private Form registrationForm;

    //Campos que hay en la página tml
    @Component(id = "numerolinea")
    private TextField numerolineaField;
    @Component(id = "codigo")
    private TextField codigoField;             
    @Component(id = "descripcion")
    private TextField descripcionField;
    @Component(id = "cantidad")
    private TextField cantidadField;   
    @Component(id = "precio")
    private TextField precioField; 
    @Component(id = "importe")
    private TextField importeField; 
    
      
    //Librería que muestra los mensajes de error en el formulario
    @Inject
    private Messages messages;
    
    
    @InjectPage
	private CrearPedido crearPedidoPage;
    

    

    void onActivate(Long pedidoId) {	
        if(pedidoId != null) {
            try {
                this.pedidoId = pedidoId;
            } catch (Exception e) {
                 registrationForm.recordError("error-pedido");
            }
        }        
    }
    
 void onValidateForm() {

        //Con esto tapestry comprueba que los datos que se vayan a enviar sean correctos.    
        if (!registrationForm.isValid()) {
            return;
        }
        
       
        try { 
              
                Pedido pedido = tiendaService.leerPedido(pedidoId);
                Float total=(Float.valueOf(precio))*(Float.valueOf(cantidad));
                LineaPedido linea = new LineaPedido(Integer.valueOf(numerolinea),codigo,descripcion,Integer.valueOf(cantidad),Float.valueOf(precio),total,pedido);
                tiendaService.crearLineaPedido(linea);
        } catch (Exception e) {
            registrationForm.recordError( messages
                    .get("error-lineapedido"));
        }


    }

    Object onSuccess() {
       crearPedidoPage.establecerPedidoId(pedidoId);
       return(crearPedidoPage);

    }
    
     Object onPassivate() {
    return(new Object [] {pedidoId}); 
}

}
