package com.empresa.intranet.web.pages.tienda;

import com.empresa.intranet.modelo.roles.Rol;
import com.empresa.intranet.modelo.tiendas.Tienda;
import com.empresa.intranet.modelo.serviciotienda.ServicioTienda;
import com.empresa.intranet.modelo.perfilusuario.PerfilUsuario;
import com.empresa.intranet.modelo.serviciousuario.PerfilUsuarioDetalle;
import com.empresa.intranet.modelo.util.DuplicatedInstanceException;
import com.empresa.intranet.web.pages.Index;
import com.empresa.intranet.web.services.AuthenticationPolicy;
import com.empresa.intranet.web.services.AuthenticationPolicyType;
import com.empresa.intranet.web.util.UserSession;
import org.apache.tapestry5.annotations.Component;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.corelib.components.Form;
import org.apache.tapestry5.corelib.components.TextField;
import org.apache.tapestry5.corelib.components.Submit;
import org.apache.tapestry5.ioc.Messages;
import org.apache.tapestry5.ioc.annotations.Inject;


//se le indica qué usuarios (todos, sólo autenticados, etc) pueden acceder a la pagina
@AuthenticationPolicy(AuthenticationPolicyType.AUTHENTICATED_USERS)
public class CrearTienda {

    @Property
    private Long tiendaId;
    
    @Property
    private Tienda tienda;
    
    @Property
    private String nombre;

    //Recupero los datos de la sesión del usuario
    @SessionState(create=false)
    private UserSession userSession;

    //Para recuperar la instancia del servicio del modelo
    @Inject
    private ServicioTienda tiendaService;

    //Elementos que hay en la página tml
    @Component
    private Form registrationForm;

    //Campos que hay en la página tml
    @Component(id = "nombre")
    private TextField nombreField;

    //Librería que muestra los mensajes de error en el formulario
    @Inject
    private Messages messages;


    void onActivate(Long tiendaId) {	
        if(tiendaId != null) {
            try {
                this.tiendaId = tiendaId;
                this.tienda = tiendaService.leerTienda(tiendaId);
                this.nombre = this.tienda.getNombre();
            } catch (Exception e) {
                 registrationForm.recordError("error-tienda");
            }
        }        
    }

    Object onPassivate() {
		return(new Object [] {tiendaId}); 
	}
    
    void onValidateForm() {

        //Con esto tapestry comprueba que los datos que se vayan a enviar sean correctos.    
        if (!registrationForm.isValid()) {
            return;
        }

        
        try {
            if(tiendaId != null) {
                this.tienda = tiendaService.leerTienda(tiendaId);
                this.tienda.setNombre(nombre);
                tiendaService.modificarTienda(tienda);
            }
            else {
                tienda = new Tienda(nombre);
                tiendaService.crearTienda(tienda);
            }     
        } catch (Exception e) {
            registrationForm.recordError( messages
                    .get("error-tienda"));
        }


    }

    Object onSuccess() {
        return Index.class;

    }

}
