package com.empresa.intranet.web.pages.tienda;

import com.empresa.intranet.modelo.roles.Rol;
import com.empresa.intranet.modelo.tipos.Tipo;
import com.empresa.intranet.modelo.serviciotienda.ServicioTienda;
import com.empresa.intranet.modelo.perfilusuario.PerfilUsuario;
import com.empresa.intranet.modelo.serviciousuario.PerfilUsuarioDetalle;
import com.empresa.intranet.modelo.util.DuplicatedInstanceException;
import com.empresa.intranet.web.pages.Index;
import com.empresa.intranet.web.services.AuthenticationPolicy;
import com.empresa.intranet.web.services.AuthenticationPolicyType;
import com.empresa.intranet.web.util.UserSession;
import org.apache.tapestry5.annotations.Component;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.corelib.components.Form;
import org.apache.tapestry5.corelib.components.TextField;
import org.apache.tapestry5.ioc.Messages;
import org.apache.tapestry5.ioc.annotations.Inject;


//se le indica qué usuarios (todos, sólo autenticados, etc) pueden acceder a la pagina
@AuthenticationPolicy(AuthenticationPolicyType.AUTHENTICATED_USERS)
public class CrearTipo {
    
    @Property
    //Con eso podemos hacer el mapeo en el tml
    private Long tipoId;    
    
    private Tipo tipo;    

    @Property
    private String nombre;

    //Recupero los datos de la sesión del usuario
    @SessionState(create=false)
    private UserSession userSession;

    //Para recuperar la instancia del servicio del modelo
    @Inject
    private ServicioTienda tiendaService;

    //Elementos que hay en la página tml
    @Component
    private Form registrationForm;

    //Campos que hay en la página tml
    @Component(id = "nombre")
    private TextField nombreField;

    //Librería que muestra los mensajes de error en el formulario
    @Inject
    private Messages messages;
    
    
    void onActivate(Long tipoId) {	
        if(tipoId != null) {
            try {
                this.tipoId = tipoId;
                this.tipo = tiendaService.leerTipo(this.tipoId);               
                this.nombre = this.tipo.getNombre();                    
            } catch (Exception e) {
                 registrationForm.recordError("error-tipo");
            }
        }        
    }
    
   Object onPassivate() {
    return(new Object [] {tipoId}); 
} 


    void onValidateForm() {

        //Con esto tapestry comprueba que los datos que se vayan a enviar sean correctos.    
        if (!registrationForm.isValid()) {
            return;
        }

        

        try {
            if (tipoId!=null){
                this.tipo = tiendaService.leerTipo(tipoId);
                this.tipo.setNombre(nombre);
                tiendaService.modificarTipo(tipo);
            }
            else{
                Tipo tipo = new Tipo(nombre);
                tiendaService.crearTipo(tipo);
            }
            
        } catch (Exception e) {
            registrationForm.recordError( messages
                    .get("error-tipo"));
        }


    }

    Object onSuccess() {
        return Index.class;

    }

}
