package com.empresa.intranet.web.pages.tienda;

import com.empresa.intranet.modelo.incidencias.Incidencia;
import com.empresa.intranet.modelo.perfilusuario.PerfilUsuario;
import com.empresa.intranet.modelo.serviciotienda.ServicioTienda;
import com.empresa.intranet.modelo.serviciousuario.ServicioUsuario;
import com.empresa.intranet.web.services.AuthenticationPolicy;
import com.empresa.intranet.web.services.AuthenticationPolicyType;
import com.empresa.intranet.web.util.IncidenciaGridDataSource;
import com.empresa.intranet.web.util.UserSession;
import java.text.Format;
import java.text.NumberFormat;
import java.text.ParseException;
import java.util.Locale;
import org.apache.tapestry5.annotations.InjectPage;

import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.ioc.annotations.Inject;


@AuthenticationPolicy(AuthenticationPolicyType.AUTHENTICATED_USERS)
public class ListaIncidencias {
	private final static int ROWS_PER_PAGE = 2;


	@Property
	private Incidencia incidencia;
	
	private IncidenciaGridDataSource incidenciaGridDataSource;

	@Inject
	private Locale locale;

	@Inject
	private ServicioTienda tiendaService;
        
        @InjectPage
	private ListaIncidencias listaIncidenciasPage;
        
        private Long idTienda;    //campo por el que se va a buscar en el formulario
        
        //Filtros en funcion del perfil de usuario
        @SuppressWarnings("unused")
        @Property
        @SessionState(create=false)
        private UserSession userSession; 
        
        @Inject
        private ServicioUsuario serviciousuario;        
              
    
	public IncidenciaGridDataSource getIncidenciaGridDataSource() {
		return incidenciaGridDataSource;
	}

	public Format getNumberFormat() {
		return NumberFormat.getInstance(locale);
	}

	public int getRowsPerPage() {
		return ROWS_PER_PAGE;
	}

	public Object [] getAConsultar() {
		return(new Object [] {incidencia.getId()});
	}
	
        public Long getIdTienda() {
		return(idTienda);
	}
	
	public void setIdTienda(Long idTienda) {
		this.idTienda = idTienda;
	}
        
        Object onSuccess() {
            listaIncidenciasPage.setIdTienda(idTienda);
            return(listaIncidenciasPage);
        }
        
	void onActivate(Long idTienda)
		throws ParseException {
            
                Long idUsuario = userSession.getPerfilUsuarioId();                
                PerfilUsuario usuario = serviciousuario.leerUsuario(idUsuario);
                //Filtro por tienda para usuarios no administradores
                if (userSession.getEsAdmin() != true)
                    idTienda=usuario.getTienda().getId();            

		incidenciaGridDataSource = new IncidenciaGridDataSource(
			tiendaService, ROWS_PER_PAGE, idTienda);
   
	}

	Object[] onPassivate() {
		return new Object[] {idTienda};
	}
        
        Object onActionFromEliminar(long incidenciaId) {
            Incidencia incidencia = tiendaService.leerIncidencia(incidenciaId);            
            tiendaService.eliminarIncidencia(incidencia);
            return listaIncidenciasPage;
        }          

}
