package com.empresa.intranet.web.pages.usuario;

import com.empresa.intranet.modelo.perfilusuario.PerfilUsuario;
import com.empresa.intranet.modelo.roles.Rol;
import com.empresa.intranet.modelo.serviciousuario.PasswordIncorectaException;
import com.empresa.intranet.modelo.serviciousuario.ServicioUsuario;
import com.empresa.intranet.web.pages.Index;
import com.empresa.intranet.web.services.AuthenticationPolicy;
import com.empresa.intranet.web.services.AuthenticationPolicyType;
import com.empresa.intranet.web.util.CookiesManager;
import com.empresa.intranet.web.util.UserSession;
import javax.management.InstanceNotFoundException;
import org.apache.tapestry5.annotations.Component;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.corelib.components.Form;
import org.apache.tapestry5.ioc.Messages;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.services.Cookies;


@AuthenticationPolicy(AuthenticationPolicyType.NON_AUTHENTICATED_USERS)
public class Login {

    @Property
    private String loginName;

    @Property
    private String password;

    @Property
    private boolean rememberMyPassword;

    @SessionState(create=false)
    private UserSession userSession;

    @Inject
    private Cookies cookies;

    @Component
    private Form loginForm;

    @Inject
    private Messages messages;

    @Inject
    private ServicioUsuario userService;

    private PerfilUsuario perfilUsuario = null;


    void onValidateForm() {

        if (!loginForm.isValid()) {
            return;
        }

        try {
            perfilUsuario = userService.login(loginName, password, false);
        } catch (InstanceNotFoundException e) {
            loginForm.recordError(messages.get("error-authenticationFailed"));
        } catch (PasswordIncorectaException e) {
            loginForm.recordError(messages.get("error-authenticationFailed"));
        }

    }

    Object onSuccess() {

    	userSession = new UserSession();
        userSession.setPerfilUsuarioId(perfilUsuario.getPerfilUsuarioId());
        userSession.setFirstName(perfilUsuario.getFirstName());
        
        boolean esAdmin = false;
        Rol rol = perfilUsuario.getRol();
        if(rol != null && rol.getId() == 1)
            esAdmin = true;
        userSession.setEsAdmin(esAdmin);
        
        if (rememberMyPassword) {
            CookiesManager.leaveCookies(cookies, loginName, perfilUsuario
                    .getEncryptedPassword());
        }
        return Index.class;

    }
	
}
