package com.empresa.intranet.web.pages.usuario;

import com.empresa.intranet.modelo.roles.Rol;
import com.empresa.intranet.modelo.perfilusuario.PerfilUsuario;
import com.empresa.intranet.modelo.serviciousuario.PerfilUsuarioDetalle;
import com.empresa.intranet.modelo.serviciousuario.ServicioUsuario;
import com.empresa.intranet.modelo.tiendas.Tienda;
import com.empresa.intranet.modelo.util.DuplicatedInstanceException;
import com.empresa.intranet.web.pages.Index;
import com.empresa.intranet.web.services.AuthenticationPolicy;
import com.empresa.intranet.web.services.AuthenticationPolicyType;
import com.empresa.intranet.web.util.UserSession;
import org.apache.tapestry5.annotations.Component;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.corelib.components.Form;
import org.apache.tapestry5.corelib.components.PasswordField;
import org.apache.tapestry5.corelib.components.TextField;
import org.apache.tapestry5.ioc.Messages;
import org.apache.tapestry5.ioc.annotations.Inject;



@AuthenticationPolicy(AuthenticationPolicyType.ADMIN_USERS)
public class Registro {

    @Property
    private String loginName;

    @Property
    private String password;

    @Property
    private String retypePassword;

    @Property
    private String firstName;

    @Property
    private String lastName;

    @Property
    private String email;
    
    @Property
    private String idRol;    
    
    @Property
    private String idTienda;       

    @SessionState(create=false)
    private UserSession userSession;

    @Inject
    private ServicioUsuario userService;

    @Component
    private Form registrationForm;

    @Component(id = "loginName")
    private TextField loginNameField;

    @Component(id = "password")
    private PasswordField passwordField;

    @Inject
    private Messages messages;

    private Long perfilUsuarioId;

    void onValidateForm() {

        if (!registrationForm.isValid()) {
            return;
        }

        if (!password.equals(retypePassword)) {
            registrationForm.recordError(passwordField, messages
                    .get("error-passwordsDontMatch"));
        } else {

            try {
                //Rol rol = userService.getRol(Long.getLong(idRol));
                Rol rol = userService.getRol(Long.valueOf(idRol));
                Tienda tienda = userService.getTienda(Long.valueOf(idTienda));
                PerfilUsuario perfilUsuario = userService.registerUser(loginName, password,
                    new PerfilUsuarioDetalle(firstName, lastName, email,rol,tienda));
                perfilUsuarioId = perfilUsuario.getPerfilUsuarioId();
            } catch (DuplicatedInstanceException e) {
                registrationForm.recordError(loginNameField, messages
                        .get("error-loginNameAlreadyExists"));
            }

        }

    }

    Object onSuccess() {

        userSession = new UserSession();
        userSession.setPerfilUsuarioId(perfilUsuarioId);
        userSession.setFirstName(firstName);
        return Index.class;

    }

}
