package com.empresa.intranet.web.services;

import com.empresa.intranet.modelo.perfilusuario.PerfilUsuario;
import com.empresa.intranet.modelo.serviciousuario.PasswordIncorectaException;
import com.empresa.intranet.modelo.serviciousuario.ServicioUsuario;
import com.empresa.intranet.web.util.CookiesManager;
import com.empresa.intranet.web.util.UserSession;
import java.io.IOException;
import javax.management.InstanceNotFoundException;

import org.apache.tapestry5.services.ApplicationStateManager;
import org.apache.tapestry5.services.Cookies;
import org.apache.tapestry5.services.Request;
import org.apache.tapestry5.services.RequestFilter;
import org.apache.tapestry5.services.RequestHandler;
import org.apache.tapestry5.services.Response;


public class SessionFilter implements RequestFilter {

	private ApplicationStateManager applicationStateManager;
	private Cookies cookies;
	private ServicioUsuario userService;

	public SessionFilter(ApplicationStateManager applicationStateManager,
			Cookies cookies, ServicioUsuario userService) {
		
		this.applicationStateManager = applicationStateManager;
		this.cookies = cookies;
		this.userService = userService;
		
	}

        @Override
	public boolean service(Request request, Response response,
			RequestHandler handler) throws IOException {

		if (!applicationStateManager.exists(UserSession.class)) {

			String loginName = CookiesManager.getLoginName(cookies);
			if (loginName != null) {

				String encryptedPassword = CookiesManager
						.getEncryptedPassword(cookies);
				if (encryptedPassword != null) {

					try {

						PerfilUsuario perfilUsuario = userService.login(loginName,
								encryptedPassword, true);
						UserSession userSession = new UserSession();
						userSession.setPerfilUsuarioId(perfilUsuario
								.getPerfilUsuarioId());
						userSession.setFirstName(perfilUsuario.getFirstName());
						applicationStateManager.set(UserSession.class,
								userSession);

					} catch (InstanceNotFoundException e) {
						CookiesManager.removeCookies(cookies);
					} catch (PasswordIncorectaException e) {
						CookiesManager.removeCookies(cookies);
					}

				}

			}

		}

		handler.service(request, response);

		return true;
	}

}
