-- ----------------------------------------------------------------------------
-- "MiniPortal" example.
-------------------------------------------------------------------------------

-- Indexes for primary keys have been explicitly created.

-- ---------- Table for validation queries from the connection pool. ----------

DROP TABLE PingTable;
CREATE TABLE PingTable (foo CHAR(1));

-- ------------------------------ PerfilUsuario ----------------------------------

DROP TABLE PerfilUsuario;
DROP TABLE Rol;
DROP TABLE Incidencia;
DROP TABLE Origen;
DROP TABLE Tipo;
DROP TABLE LineaPedido;
DROP TABLE Pedido;
DROP TABLE Tienda;

CREATE TABLE [dbo].[Rol](
	[id] [bigInt] NOT NULL IDENTITY (1,1),
	[descripcion] [nvarchar](50) COLLATE Modern_Spanish_CI_AS NULL,
 CONSTRAINT [PK_Rol] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]

INSERT INTO [dbo].[Rol] VALUES ('central')
INSERT INTO [dbo].[Rol] VALUES ('tienda')

CREATE TABLE [dbo].[Tienda](
	[id] [bigInt] NOT NULL IDENTITY (1,1),
	[nombre] [nvarchar](50) COLLATE Modern_Spanish_CI_AS NOT NULL,
 CONSTRAINT [PK_Tienda] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]

insert into tienda (nombre) values('Coruña')

CREATE TABLE [dbo].[PerfilUsuario](
	[usrId] [bigint] NOT NULL IDENTITY (1,1),
	[loginName] [varchar](30) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[enPassword] [varchar](50) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[firstName] [varchar](30) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[lastName] [varchar](40) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[email] [varchar](60) COLLATE Modern_Spanish_CI_AS NOT NULL,	
	[idRol] [bigInt] NOT NULL,
	[idTienda] [bigInt] NOT NULL,
 CONSTRAINT [FK_rol] FOREIGN KEY([idRol]) REFERENCES [dbo].[Rol] ([id]),
 CONSTRAINT [FK_tienda] FOREIGN KEY([idTienda]) REFERENCES [dbo].[Tienda] ([id]),
 CONSTRAINT [PK_PerfilUsuario] PRIMARY KEY CLUSTERED 
(
	[usrId] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY],
 CONSTRAINT [LoginNameUniqueKey] UNIQUE NONCLUSTERED 
(
	[loginName] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]


CREATE TABLE [dbo].[Tipo](
	[id] [bigInt] NOT NULL IDENTITY (1,1),
	[nombre] [nvarchar](50) COLLATE Modern_Spanish_CI_AS NOT NULL,
 CONSTRAINT [PK_Tipo] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]

CREATE TABLE [dbo].[Origen](
	[id] [bigint] NOT NULL IDENTITY (1,1),
	[nombre] [nvarchar](50) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[idTipo] [bigint] NOT NULL,
 CONSTRAINT [PK_Origen] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]

ALTER TABLE [dbo].[Origen]  WITH CHECK ADD  CONSTRAINT [FK_Origen_Tipo] FOREIGN KEY([idTipo])
REFERENCES [dbo].[Tipo] ([id])


CREATE TABLE [dbo].[Incidencia](
	[id] [bigint] NOT NULL IDENTITY (1,1),
	[numero] [bigint] NOT NULL,
	[idTienda] [bigint] NOT NULL,
	[fechaalta] [datetime] NOT NULL,
	[detectadapor] [nvarchar](50) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[recepcionada] [smallint] NULL,
	[numeroalbaran] [nvarchar](50) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[numerolinea] [bigint] NOT NULL,
	[descripcion] [nvarchar](250) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[idOrigen] [bigint] NOT NULL,
	[idTipo] [bigint] NOT NULL,
 CONSTRAINT [PK_Incidencia] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]

ALTER TABLE [dbo].[Incidencia]  WITH CHECK ADD  CONSTRAINT [fk_incidencias_origenes] FOREIGN KEY([idOrigen])
REFERENCES [dbo].[Origen] ([id])
ALTER TABLE [dbo].[Incidencia]  WITH CHECK ADD  CONSTRAINT [FK_Incidencia_Tienda] FOREIGN KEY([idTienda])
REFERENCES [dbo].[Tienda] ([id])
ALTER TABLE [dbo].[Incidencia]  WITH CHECK ADD  CONSTRAINT [fk_incidencias_tipos] FOREIGN KEY([idTipo])
REFERENCES [dbo].[Tipo] ([id])

CREATE TABLE [dbo].[Pedido](
	[id] [bigint] NOT NULL IDENTITY (1,1),
	[numero] [bigint] NOT NULL,
	[idTienda] [bigint] NOT NULL,
	[fechaalta] [datetime] NOT NULL,
	[recepcionado] [smallint] NULL,
 CONSTRAINT [PK_Pedido] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]

ALTER TABLE [dbo].[Pedido]  WITH CHECK ADD  CONSTRAINT [FK_Pedido_Tiendas] FOREIGN KEY([idTienda])
REFERENCES [dbo].[Tienda] ([id])

CREATE TABLE [dbo].[LineaPedido](
	[id] [bigint] NOT NULL IDENTITY (1,1),
	[numeroLinea] [bigint] NOT NULL,
	[codigo] [nvarchar](15) COLLATE Modern_Spanish_CI_AS NOT NULL,
	[descripcion] [nvarchar](100) COLLATE Modern_Spanish_CI_AS NULL,
	[cantidad] [int] NULL,
	[precio] [float] NULL,
	[importe] [float] NULL,
	[idPedido] [bigint] NOT NULL,
 CONSTRAINT [PK__LinneasPedido__164452B1] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]

ALTER TABLE [dbo].[LineaPedido]  WITH CHECK ADD  CONSTRAINT [fk_linpedido_pedido] FOREIGN KEY([idPedido])
REFERENCES [dbo].[Pedido] ([id])

insert into PerfilUsuario (loginName,enPassword,firstName,lastName,email,idRol,idTienda) values('central','OI9GAobMN74N4y0cnsKtqkeDrOKBQh7k80Vlpu3dY5Q=','Iván','Becerra','ibecerra@intranet.com',1,1)
insert into PerfilUsuario (loginName,enPassword,firstName,lastName,email,idRol,idTienda) values('tienda','OI9GAobMN74N4y0cnsKtqkeDrOKBQh7k80Vlpu3dY5Q=','Iván','Becerra','ibecerra@intranet.com',2,1)
insert into tipo (nombre) values('Tipo 1')
insert into origen (nombre,idTipo) values('Origen 1',1)